Documentation
¶
Index ¶
- type Manager
- func (bm *Manager) Close() error
- func (bm *Manager) GetExistingOffsetForVMA(vmaStart, vmaSize uint64) (tmpOffset TmpOffset, ok bool)
- func (bm *Manager) GetMmapPointer(offset TmpOffset) (unsafe.Pointer, error)
- func (bm *Manager) GetOffsetForVMA(vmaStart, vmaSize uint64) TmpOffset
- func (bm *Manager) PunchHole(offset TmpOffset, length uint64) error
- func (bm *Manager) WriteData(offset TmpOffset, data []byte) error
- func (bm *Manager) WriteDataTo(writer io.WriterAt, writerOffset int64, tmpOffset TmpOffset, size uint64) error
- type TmpOffset
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Manager ¶
type Manager struct {
// contains filtered or unexported fields
}
Manager manages a temporary file for buffering memory data.
func NewBufferManager ¶
NewBufferManager creates a new BufferManager with a temporary file
func (*Manager) GetExistingOffsetForVMA ¶
GetExistingOffsetForVMA returns the offset in the temp file for the given VMA if it exists.
func (*Manager) GetMmapPointer ¶
GetMmapPointer returns a pointer to the mmap data at the given offset.
func (*Manager) GetOffsetForVMA ¶
GetOffsetForVMA returns the offset in the temp file for the given VMA.
Click to show internal directories.
Click to hide internal directories.